/*
 * pCOS sample application for demonstrating dynamic loading of the pCOS DLL.
 *
 * This variant dumps only a subset of the available information, for the
 * full set see the dumper.c example.
 *
 * $Id: dumperdl.c,v 1.2 2010/09/10 14:23:21 stm Exp $
 */

#include <stdio.h>
#include <stdarg.h>

#include "pcoslibdl.h"

int
main(int argc, char **argv)
{
    const pCOS_api *pcos_api;
    pCOS *p;

    if (argc != 2)
    {   
        fprintf(stderr, "usage: dumperdl <filename>\n");
        return(2);
    }

    if ((pcos_api = pCOS_new_dl(&p)) == (const pCOS_api *) 0)
    {
        fprintf(stderr, "%s: unable to load pCOS DLL\n", argv[0]);
	return 2;
    }

    pCOS_TRY_DL(pcos_api, p)
    {
	int		doc;
	const char	*docoptlist = "requiredmode=minimum";
	const char	*globaloptlist = "";

	pcos_api->pCOS_set_option(p, globaloptlist);

	doc = pcos_api->pCOS_open_document(p, argv[1], 0, docoptlist);
	if (doc == -1)
	{
	    printf("ERROR: %s\n", pcos_api->pCOS_get_errmsg(p));
	    pCOS_delete_dl(pcos_api, p);
	    return 98;
	}

	/* --------- general information (always available) */

	printf("   File name: %s\n",
            pcos_api->pCOS_pcos_get_string(p, doc, "filename"));

	printf(" PDF version: %s\n",
	    pcos_api->pCOS_pcos_get_string(p, doc, "pdfversionstring"));

	printf("  Encryption: %s\n",
	    pcos_api->pCOS_pcos_get_string(p, doc, "encrypt/description"));

	printf("   Master pw: %s\n",
	    pcos_api->pCOS_get_number(p, doc, "encrypt/master") ? "yes" : "no");

	printf("     User pw: %s\n",
	    pcos_api->pCOS_get_number(p, doc, "encrypt/user") ? "yes" : "no");

	printf("Text copying: %s\n",
	    pcos_api->pCOS_get_number(p, doc, "encrypt/nocopy") ? "no" : "yes");

	printf("  Linearized: %s\n",
	    pcos_api->pCOS_get_number(p, doc, "linearized") ? "yes" : "no");

	pcos_api->pCOS_close_document(p, doc);
    }
    pCOS_CATCH_DL(pcos_api, p)
    {
        printf("pCOS exception occurred in dumperdl:\n");
        printf("[%d] %s: %s\n",
                pcos_api->pCOS_get_errnum(p), pcos_api->pCOS_get_apiname(p),
                pcos_api->pCOS_get_errmsg(p));
    }

    pCOS_delete_dl(pcos_api, p);

    return 0;
}
